import { Folder } from '../files/folder';
import { Node } from '../files/node';
import { Column } from './column.js';
export type ContentsWithRoot = {
    folder: Folder;
    contents: Node[];
};
interface ViewData {
    /** Unique view ID */
    id: string;
    /** Translated view name */
    name: string;
    /** Translated accessible description of the view */
    caption?: string;
    /** Translated title of the empty view */
    emptyTitle?: string;
    /** Translated description of the empty view */
    emptyCaption?: string;
    /**
     * Method return the content of the  provided path
     * This ideally should be a cancellable promise.
     * promise.cancel(reason) will be called when the directory
     * change and the promise is not resolved yet.
     * You _must_ also return the current directory
     * information alongside with its content.
     */
    getContents: (path: string) => Promise<ContentsWithRoot>;
    /** The view icon as an inline svg */
    icon: string;
    /**
     * The view order.
     * If not set will be natural sorted by view name.
     */
    order?: number;
    /**
     * Custom params to give to the router on click
     * If defined, will be treated as a dummy view and
     * will just redirect and not fetch any contents.
     */
    params?: Record<string, string>;
    /**
     * This view column(s). Name and actions are
     * by default always included
     */
    columns?: Column[];
    /** The empty view element to render your empty content into */
    emptyView?: (div: HTMLDivElement) => void;
    /** The parent unique ID */
    parent?: string;
    /** This view is sticky (sent at the bottom) */
    sticky?: boolean;
    /**
     * This view has children and is expanded (by default)
     * or not. This will be overridden by user config.
     */
    expanded?: boolean;
    /**
     * Will be used as default if the user
     * haven't customized their sorting column
     */
    defaultSortKey?: string;
    /**
     * Method called to load child views if any
     */
    loadChildViews?: (view: View) => Promise<void>;
}
export declare class View implements ViewData {
    private _view;
    constructor(view: ViewData);
    get id(): string;
    get name(): string;
    get caption(): string | undefined;
    get emptyTitle(): string | undefined;
    get emptyCaption(): string | undefined;
    get getContents(): (path: string) => Promise<ContentsWithRoot>;
    get icon(): string;
    set icon(icon: string);
    get order(): number | undefined;
    set order(order: number | undefined);
    get params(): Record<string, string> | undefined;
    set params(params: Record<string, string> | undefined);
    get columns(): Column[] | undefined;
    get emptyView(): ((div: HTMLDivElement) => void) | undefined;
    get parent(): string | undefined;
    get sticky(): boolean | undefined;
    get expanded(): boolean | undefined;
    set expanded(expanded: boolean | undefined);
    get defaultSortKey(): string | undefined;
    get loadChildViews(): ((view: View) => Promise<void>) | undefined;
}
export {};
