import { IContext, ILogger, ILoggerFactory, LogLevel } from './contracts';

/**
 * @notExported
 */
export declare class LoggerBuilder {
    protected context: IContext;
    protected factory: ILoggerFactory;
    constructor(factory: ILoggerFactory);
    /**
     * Set the app name within the logging context
     *
     * @param appId App name
     */
    setApp(appId: string): LoggerBuilder;
    /**
     * Set the logging level within the logging context
     *
     * @param level Logging level
     */
    setLogLevel(level: LogLevel): this;
    /**
     * Set the user id within the logging context
     * @param uid User ID
     * @see {@link detectUser}
     */
    setUid(uid: string): LoggerBuilder;
    /**
     * Detect the currently logged in user and set the user id within the logging context
     */
    detectUser(): LoggerBuilder;
    /**
     * Detect and use logging level configured in nextcloud config
     */
    detectLogLevel(): LoggerBuilder;
    /** Build a logger using the logging context and factory */
    build(): ILogger;
}
